EmptyTable

Struct EmptyTable 

pub struct EmptyTable { /* private fields */ }
An empty plan that is useful for testing and generating plans without mapping them to actual data.

Implementations

Source

impl EmptyTable

pub fn new(schema: SchemaRef) -> Self

Initialize a new EmptyTable from a schema.

pub fn with_partitions(self, partitions: usize) -> Self

Creates a new EmptyTable with specified partition number.