Module stream

Module stream 

TableProvider for stream sources, such as FIFO files

Structs

FileStreamProvider
Stream data from the file at location
StreamConfig
The configuration for a StreamTable
StreamTable
A TableProvider for an unbounded stream source
StreamTableFactory
A TableProviderFactory for StreamTable

Enums

StreamEncoding
The data encoding for StreamTable

Traits

StreamProvider
The StreamProvider trait is used as a generic interface for reading and writing from streaming data sources (such as FIFO, Websocket, Kafka, etc.). Implementations of the provider are responsible for providing a RecordBatchReader and optionally a RecordBatchWriter.