pub struct StreamTable(/* private fields */);Expand description
A TableProvider for an unbounded stream source
Currently only reading from / appending to a single file in-place is supported, but other stream sources and sinks may be added in future.
Applications looking to read/write datasets comprising multiple files, e.g. Hadoop-style
data stored in object storage, should instead consider ListingTable.
Implementations
Sourceimpl StreamTable
impl StreamTable
Sourcepub fn new(config: Arc<StreamConfig>) -> Self
pub fn new(config: Arc<StreamConfig>) -> Self
Create a new StreamTable for the given StreamConfig