pub struct EmptyTable { /* private fields */ }Expand description
An empty plan that is useful for testing and generating plans without mapping them to actual data.
Implementations
Sourceimpl EmptyTable
impl EmptyTable